@@ -1,5 +1,5 @@
 require 'logger'
-require 'active_support/time'
+require 'tzinfo'
 
 require 'clockwork/at'
 require 'clockwork/event'
